# voxelmap

A Python library for making voxel and three-dimensional models from NumPy arrays. [[  Web  ]](https://andrewatcloud.com/voxelmap/)
<!-- <center><a href="https://andrewatcloud.com/voxelmap/"><img src="https://github.com/andrewrgarcia/voxelmap/blob/main/extra/voxeldog.png?raw=true" width="450"></a></center> -->
<a href="https://andrewatcloud.com/voxelmap/">
<img src="https://github.com/andrewrgarcia/voxelmap/blob/main/voxelmap.svg?raw=true" width="450"></a>

## Installation and Local Usage 

```ruby
pip install voxelmap
```

It is recommended you run voxelmap using a `virtualenv` virtual environment. To do so, follow the below simple protocol to create the virtual environment, run it, and install the package there:

```ruby 
virtualenv venv
source venv/bin/activate
pip install voxelmap
python [your-voxelmap-script.py]
```
To exit the virtual environment, simply type `deactivate`. To access it at any other time again, enter with the above `source venv...` command. 

## Just starting? Remote Usage with a Colab notebook (click below)

<a href="https://colab.research.google.com/drive/1RMEMgZHlk_tKAzfS4QfXLJV9joDgdh8N?usp=sharing">
<img src="https://github.com/andrewrgarcia/powerxrd/blob/main/img/colab.png?raw=true" width="300" ></a>


## Disclaimer: Use At Your Own Risk

This program is free software. It comes without any warranty, to the extent permitted by applicable law. You can redistribute it and/or modify it under the terms of the MIT LICENSE, as published by Andrew Garcia. See LICENSE below for more details.

[![License](http://img.shields.io/:license-mit-blue.svg?style=flat-square)](http://badges.mit-license.org)

**[MIT license](./LICENSE)** Copyright 2022 © <a href="https://github.com/andrewrgarcia" target="_blank">Andrew Garcia</a>.
